"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.base_provision_vdb_parameters import BaseProvisionVDBParameters
from delphix.api.gateway.model.tag import Tag
globals()['BaseProvisionVDBParameters'] = BaseProvisionVDBParameters
globals()['Tag'] = Tag
from delphix.api.gateway.model.provision_vdb_group_from_bookmark_parameters import ProvisionVDBGroupFromBookmarkParameters


class TestProvisionVDBGroupFromBookmarkParameters(unittest.TestCase):
    """ProvisionVDBGroupFromBookmarkParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testProvisionVDBGroupFromBookmarkParameters(self):
        """Test ProvisionVDBGroupFromBookmarkParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ProvisionVDBGroupFromBookmarkParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
