"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.d_sources_api import DSourcesApi  # noqa: E501


class TestDSourcesApi(unittest.TestCase):
    """DSourcesApi unit test stubs"""

    def setUp(self):
        self.api = DSourcesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_tags_dsource(self):
        """Test case for create_tags_dsource

        Create tags for a dSource.  # noqa: E501
        """
        pass

    def test_delete_tags_dsource(self):
        """Test case for delete_tags_dsource

        Delete tags for a dSource.  # noqa: E501
        """
        pass

    def test_get_dsource_by_id(self):
        """Test case for get_dsource_by_id

        Get a dSource by ID.  # noqa: E501
        """
        pass

    def test_get_dsource_snapshots(self):
        """Test case for get_dsource_snapshots

        List Snapshots for a dSource.  # noqa: E501
        """
        pass

    def test_get_dsources(self):
        """Test case for get_dsources

        List all dSources.  # noqa: E501
        """
        pass

    def test_get_tags_dsource(self):
        """Test case for get_tags_dsource

        Get tags for a dSource.  # noqa: E501
        """
        pass

    def test_search_dsources(self):
        """Test case for search_dsources

        Search for DSources.  # noqa: E501
        """
        pass

    def test_snapshot_dsource(self):
        """Test case for snapshot_dsource

        Snapshot a DSource.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
