"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.snapshots_api import SnapshotsApi  # noqa: E501


class TestSnapshotsApi(unittest.TestCase):
    """SnapshotsApi unit test stubs"""

    def setUp(self):
        self.api = SnapshotsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_snapshot_by_id(self):
        """Test case for get_snapshot_by_id

        Get a Snapshot by ID.  # noqa: E501
        """
        pass

    def test_get_snapshots(self):
        """Test case for get_snapshots

        Retrieve the list of snapshots.  # noqa: E501
        """
        pass

    def test_get_snapshots_day_ranges(self):
        """Test case for get_snapshots_day_ranges

        Returns the count of TimeFlow snapshots of the timeflow aggregated by day. The time zone \\ used to perform the computation is the time zone of the last snapshot of the timeflow.   # noqa: E501
        """
        pass

    def test_search_snapshots(self):
        """Test case for search_snapshots

        Search snapshots.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
